=====================================================
``gordon-janitor``: Reconciliation Service for Gordon
=====================================================

.. include:: ../README.rst
   :start-after: desc-begin
   :end-before: desc-end


Release v\ |release| (:doc:`What's new? <changelog>`).

.. warning::

    This is still in the planning phase and under active development. Gordon-Janitor should not be used in production, yet.

.. include:: ../README.rst
   :start-after: intro-begin


User's Guide
============

.. toctree::
   :maxdepth: 1

   config
   plugins
   interfaces
   api


Project Information
===================

.. toctree::
   :maxdepth: 1

   license
   contributing
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
